=======
History
=======

0.5.1 (2018-03-30)
------------------

* Fix ListNode passing wrong yaml node for child


0.5.0 (2018-03-30)
------------------

* Add support for "variables"


0.4.1 (2018-01-31)
------------------

* Give DictNode default instance access to parent and context
* Update README badges


0.4.0 (2017-06-07)
------------------

* Add RegexNode
* DictNode fields know what their dict key was


0.3.0 (2017-05-31)
------------------

* Add TypelessNode
* Add BoolNode
* Use yaml.safe_load
* Allow DictNode field to have a default value of None


0.2.0 (2017-04-05)
------------------

* Cleanup package release tooling and documentation
* Fix a bit of broken documentation
* Start some basic Sphinx documentation for classes


0.1.0 (2017-03-30)
------------------

* First release on PyPI.
